==> eiffelstudio-18.11.10.2592.tar: F_code/C7/ew324.c <==
/*
 * Code for class EW_SYSTEM_EXECUTION
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew324.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_SYSTEM_EXECUTION}.make */
void F923_6485 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4, EIF_REFERENCE arg5, EIF_REFERENCE arg6, EIF_REFERENCE arg7, EIF_REFERENCE arg8)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(11);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,arg4);
	RTLR(4,arg5);
	RTLR(5,arg1);
	RTLR(6,arg2);
	RTLR(7,arg3);
	RTLR(8,arg6);
	RTLR(9,arg7);
	RTLR(10,arg8);
	RTLIU(11);
	
	RTEAA("make", 922, Current, 1, 8, 12788);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {625,894,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		tr1 = RTLNS(typres0.id, 625, _OBJSIZ_2_3_0_1_0_0_0_0_);
	}
	F626_3479(RTCW(tr1));
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	if ((EIF_BOOLEAN) eif_builtin_PLATFORM_is_windows) {
		RTHOOK(3);
		tr1 = RTMS32_EX_H("/\000\000\000c\000\000\000",2,12131);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2579[Dtype(loc1)-509])(RTCW(loc1), tr1);
	}
	RTHOOK(4);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2579[Dtype(loc1)-509])(RTCW(loc1), arg4);
	RTHOOK(5);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2579[Dtype(loc1)-509])(RTCW(loc1), arg5);
	RTHOOK(6);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2579[Dtype(loc1)-509])(RTCW(loc1), arg1);
	RTHOOK(7);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R2560[Dtype(loc1)-575])(RTCW(loc1));
	RTHOOK(8);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2875[Dtype(loc1)-613])(RTCW(loc1), arg2);
	RTHOOK(9);
	tr1 = RTOUCR(275,F923_6487,(Current));
	F922_6464(Current, tr1, loc1, arg3, arg6, arg7, arg8);
	RTHOOK(10);
	RTLE;
	RTEE;
}

/* {EW_SYSTEM_EXECUTION}.next_execution_result_type */
EIF_REFERENCE F923_6486 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("next_execution_result_type", 922, Current, 0, 0, 12789);
	RTGC;
	RTHOOK(1);
	RTCT0("callable", EX_CHECK);
		RTCF0;
	RTHOOK(2);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) 0;
}

/* {EW_SYSTEM_EXECUTION}.shell_command */
static EIF_REFERENCE F923_6487_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(275)

	RTLI(3);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,Current);
	RTLIU(3);
	
	RTEAA("shell_command", 922, Current, 0, 0, 12790);
	RTGC;
	RTOTP;
	RTHOOK(1);
	if ((EIF_BOOLEAN) eif_builtin_PLATFORM_is_windows) {
		RTHOOK(2);
		tr1 = RTLNS(eif_new_type(201, 0x00).id, 201, _OBJSIZ_0_0_0_1_0_0_0_0_);
		tr2 = RTMS_EX_H("COMSPEC",7,916208451);
		Result = F202_2257(RTCW(tr1), tr2);
		RTHOOK(3);
		if ((EIF_BOOLEAN)(Result == NULL)) {
			RTHOOK(4);
			Result = RTMS32_EX_H("c\000\000\000m\000\000\000d\000\000\000.\000\000\000e\000\000\000x\000\000\000e\000\000\000",7,1429768549);
		}
	} else {
		RTHOOK(5);
		Result = RTMS32_EX_H("/\000\000\000b\000\000\000i\000\000\000n\000\000\000/\000\000\000s\000\000\000h\000\000\000",7,2075682408);
	}
	RTOTE;
	RTHOOK(7);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F923_6487 (EIF_REFERENCE Current)
{
	GTCX
	return RTOUCR(275,F923_6487_body,(Current));
}

void EIF_Minit324 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C7/ew324.c <==
/*
 * Code for class EW_SYSTEM_EXECUTION
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew324.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_SYSTEM_EXECUTION}.make */
void F923_6506 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4, EIF_REFERENCE arg5, EIF_REFERENCE arg6, EIF_REFERENCE arg7, EIF_REFERENCE arg8)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(11);
	RTLR(0,loc1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,arg4);
	RTLR(4,arg5);
	RTLR(5,arg1);
	RTLR(6,arg2);
	RTLR(7,arg3);
	RTLR(8,arg6);
	RTLR(9,arg7);
	RTLR(10,arg8);
	RTLIU(11);
	
	RTEAA("make", 922, Current, 1, 8, 12823);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {625,894,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(Dftype(Current), typarr0)));
		loc1 = RTLNS(typres0.id, 625, _OBJSIZ_2_3_0_1_0_0_0_0_);
	}
	F626_3486(RTCW(loc1));
	RTHOOK(2);
	if ((EIF_BOOLEAN) eif_builtin_PLATFORM_is_windows) {
		RTHOOK(3);
		tr1 = RTMS32_EX_H("/\000\000\000c\000\000\000",2,12131);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2581[Dtype(RTCW(loc1))-625])(loc1, tr1);
	}
	RTHOOK(4);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2581[Dtype(RTCW(loc1))-625])(loc1, arg4);
	RTHOOK(5);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2581[Dtype(RTCW(loc1))-625])(loc1, arg5);
	RTHOOK(6);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2581[Dtype(RTCW(loc1))-625])(loc1, arg1);
	RTHOOK(7);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R2562[Dtype(RTCW(loc1))-625])(loc1);
	RTHOOK(8);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2882[Dtype(RTCW(loc1))-625])(loc1, arg2);
	RTHOOK(9);
	tr1 = RTOUCR(270,F923_6508, (Current));
	F922_6485(Current, tr1, loc1, arg3, arg6, arg7, arg8);
	RTHOOK(10);
	RTLE;
	RTEE;
}

/* {EW_SYSTEM_EXECUTION}.next_execution_result_type */
EIF_REFERENCE F923_6507 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("next_execution_result_type", 922, Current, 0, 0, 12824);
	RTGC;
	RTHOOK(1);
	RTCT0("callable", EX_CHECK);
		RTCF0;
	RTHOOK(2);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) 0;
}

/* {EW_SYSTEM_EXECUTION}.shell_command */
static EIF_REFERENCE F923_6508_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
#define Result RTOTRR
	RTOUDR(270)

	RTLI(3);
	RTLR(0,tr1);
	RTLR(1,tr2);
	RTLR(2,Current);
	RTLIU(3);
	
	RTEAA("shell_command", 922, Current, 0, 0, 12825);
	RTGC;
	RTOTP;
	RTHOOK(1);
	if ((EIF_BOOLEAN) eif_builtin_PLATFORM_is_windows) {
		RTHOOK(2);
		tr1 = RTLNS(eif_new_type(201, 0x00).id, 201, _OBJSIZ_0_0_0_1_0_0_0_0_);
		tr2 = RTMS_EX_H("COMSPEC",7,916208451);
		Result = F202_2257(RTCW(tr1), tr2);
		RTHOOK(3);
		if ((EIF_BOOLEAN)(Result == NULL)) {
			RTHOOK(4);
			Result = RTMS32_EX_H("c\000\000\000m\000\000\000d\000\000\000.\000\000\000e\000\000\000x\000\000\000e\000\000\000",7,1429768549);
		}
	} else {
		RTHOOK(5);
		Result = RTMS32_EX_H("/\000\000\000b\000\000\000i\000\000\000n\000\000\000/\000\000\000s\000\000\000h\000\000\000",7,2075682408);
	}
	RTOTE;
	RTHOOK(7);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F923_6508 (EIF_REFERENCE Current)
{
	GTCX
	return RTOUCR(270,F923_6508_body,(Current));
}

void EIF_Minit324 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
